payConfig property
Config class necessary to hold all the necessary informations needed to initialize the SDK.
Implementation
final KhaltiPayConfig payConfig;
Config class necessary to hold all the necessary informations needed to initialize the SDK.
final KhaltiPayConfig payConfig;