KhaltiEvent enum
Various events associated with different actions.
Values
- kpgDisposed → const KhaltiEvent
-
Event for when khalti payment page is disposed.
- returnUrlLoadFailure → const KhaltiEvent
-
Event for when return url fails to load from the API.
- networkFailure → const KhaltiEvent
-
Event for when there's an exception when making a network call.
- paymentLookupfailure → const KhaltiEvent
-
Event for when there's a HTTP failure when making a network call for verifying payment status.
- unknown → const KhaltiEvent
-
An unknown event.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
KhaltiEvent> - A constant List of the values in this enum, in order of their declaration.