PaymentPayload class

Response model for payment verification lookup.

Constructors

PaymentPayload({String? pidx, int totalAmount = 0, required String? status, required String? transactionId, int fee = 0, bool refunded = false, String? purchaseOrderId, String? purchaseOrderName, Map<String, dynamic>? extraMerchantParams})
Default constructor for PaymentPayload.
const
PaymentPayload.fromJson(Map<String, dynamic> map)
Factory to create PaymentPayload instance from map.
factory

Properties

extraMerchantParams Map<String, dynamic>?
Extra information associated with the merchant making the payment.
final
fee int
The service charge for the payment.
final
hashCode int
The hash code for this object.
no setterinherited
pidx String?
The product idx for the associated payment.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
purchaseOrderId String?
The id associated with the purchased item.
final
purchaseOrderName String?
The name associated with the purchased item.
final
refunded bool
Denotes if refund was made in case of any failure.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
The transaction status for the payment made.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
totalAmount int
Total Amount associated with the payment made.
final
transactionId String?
Unique transaction id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited