PaymentResult class
The result after making either a successful or unsuccessful payment.
Constructors
- PaymentResult({PaymentPayload? payload})
-
Constructor for PaymentResult.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- payload → PaymentPayload?
-
Payload regarding the product purchased.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
If set to
true, the toString method will be overridden to output this instance's props.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited