KhaltiPayConfig class
A class to hold necessary informations for loading the flutter SDK.
Constructors
- KhaltiPayConfig({required String publicKey, required String pidx, bool openInKhalti = false, Environment environment = Environment.prod})
-
A class to hold necessary informations for loading the flutter SDK.
const
Properties
- environment → Environment
-
Environment to run the SDK against.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- openInKhalti → bool
-
A boolean to determine whether to launch WebView or open in khalti app.
final
- pidx → String
-
The Payment URL to redirect to be able to make payments.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- publicKey → String
-
Public Key
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited