KhaltiService class
The wrapper class to access Khalti Payment Gateway API.
Constructors
- KhaltiService({required KhaltiClient client})
- Default constructor for KhaltiService to initialize KhaltiClient.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchPaymentDetail(
String pidx, {bool isProd = true}) → Future< PaymentDetailModel> - Fetches details regarding payment that is to be made.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
String pidx, {bool isProd = true}) → Future< PaymentPayload> - Checks the status of the payment.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- enableDebugging ↔ bool
-
Enabling enableDebugging will print network logs.
getter/setter pair
- publicKey ↔ String
-
The publicKey configured using KhaltiService.publicKey.
getter/setter pair