PaymentDetailModel class
This class holds necessary information that is necessary for the payment webview to load.
Constructors
- PaymentDetailModel({String? returnUrl})
-
Constructor for
PaymentDetailModel.const - PaymentDetailModel.empty()
-
Helper factory constructor to return an instance of
PaymentDetailModelwith no return url.factory -
PaymentDetailModel.fromJson(Map<
String, dynamic> map) -
Factory to create PaymentDetailModel instance from
map.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- returnUrl → String?
-
The
return_urlassociated with the payment.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited